==> nova_utils-0.0.1.tar.gz: ios/Classes/NovaUtilsPlugin.m <==
#import "NKeychainPlugin.h"
#import <UICKeyChainStore/UICKeyChainStore.h>

@interface NKeychainPlugin ()
@property (nonatomic, strong) NSMutableDictionary *defaultDic;
@end

@implementation NKeychainPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"n_keychain_plugin"
            binaryMessenger:[registrar messenger]];
  static NKeychainPlugin *instance;
  instance = [[NKeychainPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (instancetype)init {
    self = [super init];
    if (self) {
        NSData *defaultDicData = [[UICKeyChainStore keyChainStoreWithService:@"com.nkeychainplugin.dic"] dataForKey:@"default"];
        if (defaultDicData == nil) {
            self.defaultDic = [NSMutableDictionary dictionary];
        } else {
            self.defaultDic = [NSMutableDictionary dictionaryWithDictionary: [NSJSONSerialization JSONObjectWithData:defaultDicData options:0 error:nil]];
        }
        NSLog(@"[NKeychainPlugin] read dic from keychain: %@", self.defaultDic);
    }
    
    return self;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getKeyChainValue" isEqualToString:call.method]) {
      NSArray *keys = call.arguments;
      NSMutableDictionary<NSString *, NSString *> *dic = [[NSMutableDictionary alloc] init];
      [keys enumerateObjectsUsingBlock:^(NSString * _Nonnull obj, NSUInteger idx, BOOL * _Nonnull stop) {
          id value = self.defaultDic[obj];
          if (value != nil) {
              dic[obj] = value;
          }
      }];
      
      result(dic);
  } else if ([@"setKeyChainValue" isEqualToString:call.method]) {
      NSDictionary *dic = call.arguments;
      
      [dic enumerateKeysAndObjectsUsingBlock:^(id  _Nonnull key, id  _Nonnull obj, BOOL * _Nonnull stop) {
          [self.defaultDic setObject:obj forKey:key];
      }];
      
      NSData *defaultDicData = [NSJSONSerialization dataWithJSONObject:self.defaultDic options:0 error:nil];
      [[UICKeyChainStore keyChainStoreWithService:@"com.nkeychainplugin.dic"] setData:defaultDicData forKey:@"default"];
      result([NSNumber numberWithBool:true]);
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}

@end

==> nova_utils-0.0.8.tar.gz: ios/Classes/NovaUtilsPlugin.m <==
#import "NovaUtilsPlugin.h"
#import <UICKeyChainStore/UICKeyChainStore.h>

@interface NovaUtilsPlugin ()
@property (nonatomic, strong) NSMutableDictionary *defaultDic;
@end

@implementation NovaUtilsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"nova_utils"
            binaryMessenger:[registrar messenger]];
  static NovaUtilsPlugin *instance;
  instance = [[NovaUtilsPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (instancetype)init {
    self = [super init];
    if (self) {
        NSData *defaultDicData = [[UICKeyChainStore keyChainStoreWithService:@"com.NovaUtilsPlugin.dic"] dataForKey:@"default"];
        if (defaultDicData == nil) {
            self.defaultDic = [NSMutableDictionary dictionary];
        } else {
            self.defaultDic = [NSMutableDictionary dictionaryWithDictionary: [NSJSONSerialization JSONObjectWithData:defaultDicData options:0 error:nil]];
        }
        NSLog(@"[NovaUtilsPlugin] read dic from keychain: %@", self.defaultDic);
    }
    
    return self;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getKeyChainValue" isEqualToString:call.method]) {
      NSArray *keys = call.arguments;
      NSMutableDictionary<NSString *, NSString *> *dic = [[NSMutableDictionary alloc] init];
      [keys enumerateObjectsUsingBlock:^(NSString * _Nonnull obj, NSUInteger idx, BOOL * _Nonnull stop) {
          id value = self.defaultDic[obj];
          if (value != nil) {
              dic[obj] = value;
          }
      }];
      
      result(dic);
  } else if ([@"setKeyChainValue" isEqualToString:call.method]) {
      NSDictionary *dic = call.arguments;
      
      [dic enumerateKeysAndObjectsUsingBlock:^(id  _Nonnull key, id  _Nonnull obj, BOOL * _Nonnull stop) {
          [self.defaultDic setObject:obj forKey:key];
      }];
      
      NSData *defaultDicData = [NSJSONSerialization dataWithJSONObject:self.defaultDic options:0 error:nil];
      [[UICKeyChainStore keyChainStoreWithService:@"com.NovaUtilsPlugin.dic"] setData:defaultDicData forKey:@"default"];
      result([NSNumber numberWithBool:true]);
  }
  else if ([@"launchMarket" isEqualToString:call.method]) {
    NSString *urlString = call.arguments;

    [[UIApplication sharedApplication] openURL:[NSURL URLWithString:urlString]];
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}

@end
